﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using Windows.ApplicationModel.Resources.Core;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Media.Imaging;
using System.Collections.Specialized;

// The data model defined by this file serves as a representative example of a strongly-typed
// model that supports notification when members are added, removed, or modified.  The property
// names chosen coincide with data bindings in the standard item templates.
//
// Applications may use this model as a starting point and build on it, or discard it entirely and
// replace it with something appropriate to their needs.

namespace FoodLight.Data
{
    /// <summary>
    /// Base class for <see cref="CategoryDataItem"/> and <see cref="CategoryDataGroup"/> that
    /// defines properties common to both.
    /// </summary>
    [Windows.Foundation.Metadata.WebHostHidden]
    public abstract class CategoryDataCommon : FoodLight.Common.BindableBase
    {
        private static Uri _baseUri = new Uri("ms-appx:///");

        public CategoryDataCommon(String uniqueId, String title, String subtitle, String imagePath, String description)
        {
            this._uniqueId = uniqueId;
            this._title = title;
            this._subtitle = subtitle;
            this._description = description;
            this._imagePath = imagePath;
        }

        private string _uniqueId = string.Empty;
        public string UniqueId
        {
            get { return this._uniqueId; }
            set { this.SetProperty(ref this._uniqueId, value); }
        }

        private string _title = string.Empty;
        public string Title
        {
            get { return this._title; }
            set { this.SetProperty(ref this._title, value); }
        }

        private string _subtitle = string.Empty;
        public string Subtitle
        {
            get { return this._subtitle; }
            set { this.SetProperty(ref this._subtitle, value); }
        }
		        private string _ReciTitle = string.Empty;
        public string ReciTitle
        {
            get { return this._ReciTitle; }
            set { this.SetProperty(ref this._ReciTitle, value); }
        }
		private string _ReciSub = string.Empty;
        public string ReciSub
        {
            get { return this._ReciSub; }
            set { this.SetProperty(ref this._ReciSub, value); }
        }

        private string _description = string.Empty;
        public string Description
        {
            get { return this._description; }
            set { this.SetProperty(ref this._description, value); }
        }

        private ImageSource _image = null;
        private String _imagePath = null;
        public ImageSource Image
        {
            get
            {
                if (this._image == null && this._imagePath != null)
                {
                    this._image = new BitmapImage(new Uri(CategoryDataCommon._baseUri, this._imagePath));
                }
                return this._image;
            }

            set
            {
                this._imagePath = null;
                this.SetProperty(ref this._image, value);
            }
        }

        public void SetImage(String path)
        {
            this._image = null;
            this._imagePath = path;
            this.OnPropertyChanged("Image");
        }

        public override string ToString()
        {
            return this.Title;
        }
    }

    /// <summary>
    /// Generic item data model.
    /// </summary>
    public class CategoryDataItem : CategoryDataCommon
    {
        public CategoryDataItem(String uniqueId, String title, String subtitle, String imagePath, String description, String content, int colSpan, int rowSpan, CategoryDataGroup group)
            : base(uniqueId, title, subtitle, imagePath, description)
        {
            this._colSpan = colSpan;
            this._rowSpan = rowSpan;
            this._content = content;
            this._group = group;
        }

        private string _content = string.Empty;
        public string Content
        {
            get { return this._content; }
            set { this.SetProperty(ref this._content, value); }
        }

        private int _rowSpan = 1;
        public int RowSpan
        {
            get { return this._rowSpan; }
            set { this.SetProperty(ref this._rowSpan, value); }
        }

        private int _colSpan = 1;
        public int ColSpan
        {
            get { return this._colSpan; }
            set { this.SetProperty(ref this._colSpan, value); }
        }


        private CategoryDataGroup _group;
        public CategoryDataGroup Group
        {
            get { return this._group; }
            set { this.SetProperty(ref this._group, value); }
        }
    }

    /// <summary>
    /// Generic group data model.
    /// </summary>
    public class CategoryDataGroup : CategoryDataCommon
    {
        public CategoryDataGroup(String uniqueId, String title, String subtitle, String imagePath, String description)
            : base(uniqueId, title, subtitle, imagePath, description)
        {
            Items.CollectionChanged += ItemsCollectionChanged;
        }

        private void ItemsCollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
        {
            // Provides a subset of the full items collection to bind to from a GroupedItemsPage
            // for two reasons: GridView will not virtualize large items collections, and it
            // improves the user experience when browsing through groups with large numbers of
            // items.
            //
            // A maximum of 12 items are displayed because it results in filled grid columns
            // whether there are 1, 2, 3, 4, or 6 rows displayed

            switch (e.Action)
            {
                case NotifyCollectionChangedAction.Add:
                    if (e.NewStartingIndex < 12)
                    {
                        TopItems.Insert(e.NewStartingIndex, Items[e.NewStartingIndex]);
                        if (TopItems.Count > 12)
                        {
                            TopItems.RemoveAt(12);
                        }
                    }
                    break;
                case NotifyCollectionChangedAction.Move:
                    if (e.OldStartingIndex < 12 && e.NewStartingIndex < 12)
                    {
                        TopItems.Move(e.OldStartingIndex, e.NewStartingIndex);
                    }
                    else if (e.OldStartingIndex < 12)
                    {
                        TopItems.RemoveAt(e.OldStartingIndex);
                        TopItems.Add(Items[11]);
                    }
                    else if (e.NewStartingIndex < 12)
                    {
                        TopItems.Insert(e.NewStartingIndex, Items[e.NewStartingIndex]);
                        TopItems.RemoveAt(12);
                    }
                    break;
                case NotifyCollectionChangedAction.Remove:
                    if (e.OldStartingIndex < 12)
                    {
                        TopItems.RemoveAt(e.OldStartingIndex);
                        if (Items.Count >= 12)
                        {
                            TopItems.Add(Items[11]);
                        }
                    }
                    break;
                case NotifyCollectionChangedAction.Replace:
                    if (e.OldStartingIndex < 12)
                    {
                        TopItems[e.OldStartingIndex] = Items[e.OldStartingIndex];
                    }
                    break;
                case NotifyCollectionChangedAction.Reset:
                    TopItems.Clear();
                    while (TopItems.Count < Items.Count && TopItems.Count < 12)
                    {
                        TopItems.Add(Items[TopItems.Count]);
                    }
                    break;
            }
        }

        private ObservableCollection<CategoryDataItem> _items = new ObservableCollection<CategoryDataItem>();
        public ObservableCollection<CategoryDataItem> Items
        {
            get { return this._items; }
        }

        private ObservableCollection<CategoryDataItem> _topItem = new ObservableCollection<CategoryDataItem>();
        public ObservableCollection<CategoryDataItem> TopItems
        {
            get { return this._topItem; }
        }
    }

    /// <summary>
    /// Creates a collection of groups and items with hard-coded content.
    /// 
    /// CategoryDataSource initializes with placeholder data rather than live production
    /// data so that sample data is provided at both design-time and run-time.
    /// </summary>
    public sealed class CategoryDataSource
    {
        private static CategoryDataSource _CategoryDataSource = new CategoryDataSource();

        private ObservableCollection<CategoryDataGroup> _allGroups = new ObservableCollection<CategoryDataGroup>();
        public ObservableCollection<CategoryDataGroup> AllGroups
        {
            get { return this._allGroups; }
        }

        public static IEnumerable<CategoryDataGroup> GetGroups(string uniqueId)
        {
            if (!uniqueId.Equals("AllGroups")) throw new ArgumentException("Only 'AllGroups' is supported as a collection of groups");

            return _CategoryDataSource.AllGroups;
        }

        public static CategoryDataGroup GetGroup(string uniqueId)
        {
            // Simple linear search is acceptable for small data sets
            var matches = _CategoryDataSource.AllGroups.Where((group) => group.UniqueId.Equals(uniqueId));
            if (matches.Count() == 1) return matches.First();
            return null;
        }

        public static CategoryDataItem GetItem(string uniqueId)
        {
            // Simple linear search is acceptable for small data sets
            var matches = _CategoryDataSource.AllGroups.SelectMany(group => group.Items).Where((item) => item.UniqueId.Equals(uniqueId));
            if (matches.Count() == 1) return matches.First();
            return null;
        }



        public CategoryDataSource()
        {
            String ITEM_CONTENT = String.Format("Item Content: {0}\n\n{0}\n\n{0}\n\n{0}\n\n{0}\n\n{0}\n\n{0}",
                        "Curabitur class aliquam vestibulum nam curae maecenas sed integer cras phasellus suspendisse quisque donec dis praesent accumsan bibendum pellentesque condimentum adipiscing etiam consequat vivamus dictumst aliquam duis convallis scelerisque est parturient ullamcorper aliquet fusce suspendisse nunc hac eleifend amet blandit facilisi condimentum commodo scelerisque faucibus aenean ullamcorper ante mauris dignissim consectetuer nullam lorem vestibulum habitant conubia elementum pellentesque morbi facilisis arcu sollicitudin diam cubilia aptent vestibulum auctor eget dapibus pellentesque inceptos leo egestas interdum nulla consectetuer suspendisse adipiscing pellentesque proin lobortis sollicitudin augue elit mus congue fermentum parturient fringilla euismod feugiat");

            var group1 = new CategoryDataGroup("Group-1",
                 "Featured Recipe",
                 "Group Subtitle: 1",
                 "Assets/DarkGray.png",
                 "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

            group1.Items.Add(new CategoryDataItem("CatNew-Group-1-Item1",
                 "Prawn Salad",
                 "",
                 "Assets/HubPage/Recipes1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT, 161, 105,
                 group1){ReciTitle="Prawn Salad", ReciSub=""});

            group1.Items.Add(new CategoryDataItem("RpsSmall-Group-1-Item2",
                 "GREEN BEAN & SWEET",
                 "POTATO SABJI (INDIAN)",
                 "Assets/HubPage/RecipesSmall1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT, 41, 53,
                 group1));

            group1.Items.Add(new CategoryDataItem("RpsSmall-Group-1-Item3",
                 "GREEN BEAN & SWEET",
                 "(INDIAN)",
                 "Assets/HubPage/RecipesSmall2.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT, 41, 52,
                 group1));
            group1.Items.Add(new CategoryDataItem("RpsSmall-Group-1-Item4",
                 "GREEN BEAN & SWEET",
                 "(INDIAN)",
                 "Assets/HubPage/Cuisines1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT, 41, 52,
                 group1));
            group1.Items.Add(new CategoryDataItem("RpsSmall-Group-1-Item5",
             "GREEN BEAN & SWEET",
             "(INDIAN)",
             "Assets/HubPage/Cuisines2.png",
             "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
            ITEM_CONTENT, 41, 52,
             group1));
            group1.Items.Add(new CategoryDataItem("RpsSmall-Group-1-Item6",
            "GREEN BEAN & SWEET",
            "(INDIAN)",
            "Assets/HubPage/Cuisines3.png",
            "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
           ITEM_CONTENT, 41, 52,
            group1));
            group1.Items.Add(new CategoryDataItem("RpsSmall-Group-1-Item7",
            "GREEN BEAN & SWEET",
            "(INDIAN)",
            "Assets/HubPage/Cuisines4.png",
            "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
           ITEM_CONTENT, 41, 52,
            group1));
            group1.Items.Add(new CategoryDataItem("RpsSmall-Group-1-Item8",
            "GREEN BEAN & SWEET",
            "(INDIAN)",
            "Assets/HubPage/Cuisines5.png",
            "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
           ITEM_CONTENT, 41, 52,
            group1));
            group1.Items.Add(new CategoryDataItem("RpsSmall-Group-1-Item9",
            "GREEN BEAN & SWEET",
            "(INDIAN)",
            "Assets/HubPage/Cuisines6.png",
            "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
           ITEM_CONTENT, 41, 52,
            group1));
            this.AllGroups.Add(group1);

         //   var group2 = new CategoryDataGroup("Group-2",
         //       "Cuisines",
         //       "Group Subtitle: 1",
         //       "Assets/DarkGray.png",
         //       "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

         //   group2.Items.Add(new CategoryDataItem("CuisinesSmall-Group-2-Item1",
         //       "Indian",
         //       "290 Recipes",
         //       "Assets/HubPage/Cuisines1.png",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 53,
         //       group2));
         //   group2.Items.Add(new CategoryDataItem("CuisinesSmall-Group-2-Item5",
         //       "Continental",
         //       "290 Recipes",
         //       "Assets/HubPage/Cuisines2.png",
         //      "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 52,
         //      group2));
         //   group2.Items.Add(new CategoryDataItem("CuisinesSmall-Group-2-Item3",
         //       "Indian",
         //       "290 Recipes",
         //       "Assets/HubPage/Cuisines3.png",
         //      "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 53,
         //      group2));
         //   group2.Items.Add(new CategoryDataItem("CuisinesSmall-Group-2-Item4",
         //       "Indian",
         //       "290 Recipes",
         //       "Assets/HubPage/Cuisines4.png",
         //      "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 52,
         //      group2));
         //   group2.Items.Add(new CategoryDataItem("CuisinesSmall-Group-2-Item5",
         //       "Indian",
         //       "290 Recipes",
         //       "Assets/HubPage/Cuisines5.png",
         //      "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 53,
         //      group2));
         //   group2.Items.Add(new CategoryDataItem("CuisinesSmall-Group-2-Item6",
         //       "Chinese",
         //       "290 Recipes",
         //       "Assets/HubPage/Cuisines6.png",
         //      "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 52,
         //      group2));
         //this.AllGroups.Add(group2);

         //   var group3 = new CategoryDataGroup("Group-3",
         //     "Dish Types",
         //     "Group Subtitle: 1",
         //     "Assets/DarkGray.png",
         //     "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

         //   group3.Items.Add(new CategoryDataItem("DishSmall-Group-3-Item1",
         //       "Breakfast",
         //       "56 Recipes",
         //       "Assets/SmallTile.jpg",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 11,
         //       group3));
         //   group3.Items.Add(new CategoryDataItem("DishSmall-Group-3-Item2",
         //       "Snacks",
         //       "145 Recipes",
         //       "Assets/SmallTile.jpg",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 11,
         //       group3));
         //   group3.Items.Add(new CategoryDataItem("DishSmall-Group-3-Item3",
         //       "Soups",
         //       "18 Recipes",
         //       "Assets/SmallTile.jpg",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 11,
         //       group3));
         //   group3.Items.Add(new CategoryDataItem("DishSmall-Group-3-Item4",
         //       "Lunch",
         //       " 203 Recipes",
         //       "Assets/SmallTile.jpg",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 12,
         //       group3));
         //   group3.Items.Add(new CategoryDataItem("DishSmall-Group-3-Item5",
         //       "Dinner",
         //       "234 Recipes",
         //       "Assets/SmallTile.jpg",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 12,
         //       group3));
         //   group3.Items.Add(new CategoryDataItem("DishSmall-Group-3-Item6",
         //       "Specials",
         //       "25 Recipes",
         //       "Assets/SmallTile.jpg",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 12,
         //       group3));
         //   group3.Items.Add(new CategoryDataItem("DishSmall-Group-3-Item7",
         //       "Dinner",
         //       "234 Recipes",
         //       "Assets/SmallTile.jpg",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 12,
         //       group3));
         //   group3.Items.Add(new CategoryDataItem("DishSmall-Group-3-Item8",
         //       "Specials",
         //       "25 Recipes",
         //       "Assets/SmallTile.jpg",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 12,
         //       group3));

         //   group3.Items.Add(new CategoryDataItem("DishSmall-Group-3-Item9",
         //       "Specials",
         //       "25 Recipes",
         //       "Assets/SmallTile.jpg",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 41, 12,
         //       group3));
         //   this.AllGroups.Add(group3);


         //   var group4 = new CategoryDataGroup("Group-4",
         //     "Popular Recipes",
         //     "Group Subtitle: 1",
         //     "Assets/DarkGray.png",
         //     "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

         //   group4.Items.Add(new CategoryDataItem("PopularBigSmall-Group-4-Item1",
         //       "Japanese Tossed Salad",
         //       "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur scelerisque purus eget enim rutrum laoreet at viverra nibh. Aenean eu ante urna.",
         //       "Assets/HubPage/PopRecipes.png",
         //       "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //       ITEM_CONTENT, 50, 105,
         //       group4));

         //   group4.Items.Add(new CategoryDataItem("PopularBigsceSmall-Group-4-Item2",
         //       "Grilled Chicken Pita Sandwiches",
         //      "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur scelerisque purus eget enim rutrum laoreet at viverra nibh. Aenean eu ante urna.",
         //      "Assets/HubPage/PopRecipes2.png",
         //      "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //      ITEM_CONTENT, 50, 105,
         //      group4));

         //   group4.Items.Add(new CategoryDataItem("PopularSmall-Group-4-Item3",
         //     "Japanese Style salmon Sashimi",
         //      "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur scelerisque purus eget enim rutrum laoreet at viverra nibh. Aenean eu ante urna.",
         //     "Assets/HubPage/PopSmallRecipes1.png",
         //     "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //     ITEM_CONTENT, 80, 54,
         //     group4));

         //   group4.Items.Add(new CategoryDataItem("PsSSmall-Group-4-Item4",
         //     "Japanese Style salmon Sashimi",
         //      "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur scelerisque purus eget enim rutrum laoreet at viverra nibh. Aenean eu ante urna.",
         //     "Assets/HubPage/PopSmallRecipes2.png",
         //     "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
         //     ITEM_CONTENT, 80, 50,
         //     group4));
         //   this.AllGroups.Add(group4);
        }
    }
}
